summaryrefslogtreecommitdiffstats
path: root/digikam/utilities/imageeditor
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:35:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:35:21 -0600
commit419fcddc00ceaddb5ec78da0b3eb84a26e3fc4ea (patch)
treeeefc3fdac16a4ec706222b50a4fa9d7825cc9f46 /digikam/utilities/imageeditor
parentc1bbc88281394639e2a92c2d1b43ca4f3e1813aa (diff)
downloaddigikam-419fcddc00ceaddb5ec78da0b3eb84a26e3fc4ea.tar.gz
digikam-419fcddc00ceaddb5ec78da0b3eb84a26e3fc4ea.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'digikam/utilities/imageeditor')
-rw-r--r--digikam/utilities/imageeditor/canvas/canvas.cpp6
-rw-r--r--digikam/utilities/imageeditor/canvas/colorcorrectiondlg.cpp4
-rw-r--r--digikam/utilities/imageeditor/canvas/dimginterface.cpp4
-rw-r--r--digikam/utilities/imageeditor/canvas/undocache.cpp16
-rw-r--r--digikam/utilities/imageeditor/editor/editorwindow.cpp38
-rw-r--r--digikam/utilities/imageeditor/editor/imageiface.cpp2
-rw-r--r--digikam/utilities/imageeditor/editor/imagewindow.cpp14
-rw-r--r--digikam/utilities/imageeditor/rawimport/rawpreview.cpp2
-rw-r--r--digikam/utilities/imageeditor/rawimport/rawsettingsbox.cpp10
-rw-r--r--digikam/utilities/imageeditor/tools/imageprint.cpp72
-rw-r--r--digikam/utilities/imageeditor/tools/imageresize.cpp2
11 files changed, 85 insertions, 85 deletions
diff --git a/digikam/utilities/imageeditor/canvas/colorcorrectiondlg.cpp b/digikam/utilities/imageeditor/canvas/colorcorrectiondlg.cpp
index 5bb7f70..571c7f6 100644
--- a/digikam/utilities/imageeditor/canvas/colorcorrectiondlg.cpp
+++ b/digikam/utilities/imageeditor/canvas/colorcorrectiondlg.cpp
@@ -79,10 +79,10 @@ ColorCorrectionDlg::ColorCorrectionDlg(TQWidget* parent, DImg *preview,
TQLabel *logo = new TQLabel(page);
TQLabel *message = new TQLabel(page);
TQLabel *currentProfileTitle = new TQLabel(i18n("Current workspace color profile:"), page);
- TQLabel *currentProfileDesc = new TQLabel(TQString("<b>%1</b>").tqarg(m_iccTrans->getOutpoutProfileDescriptor()), page);
+ TQLabel *currentProfileDesc = new TQLabel(TQString("<b>%1</b>").arg(m_iccTrans->getOutpoutProfileDescriptor()), page);
TQPushButton *currentProfInfo = new TQPushButton(i18n("Info..."), page);
TQLabel *embeddedProfileTitle = new TQLabel(i18n("Embedded color profile:"), page);
- TQLabel *embeddedProfileDesc = new TQLabel(TQString("<b>%1</b>").tqarg(m_iccTrans->getEmbeddedProfileDescriptor()), page);
+ TQLabel *embeddedProfileDesc = new TQLabel(TQString("<b>%1</b>").arg(m_iccTrans->getEmbeddedProfileDescriptor()), page);
TQPushButton *embeddedProfInfo = new TQPushButton(i18n("Info..."), page);
KSeparator *line = new KSeparator(Qt::Horizontal, page);
diff --git a/digikam/utilities/imageeditor/canvas/dimginterface.cpp b/digikam/utilities/imageeditor/canvas/dimginterface.cpp
index b9a02ff..dcc9040 100644
--- a/digikam/utilities/imageeditor/canvas/dimginterface.cpp
+++ b/digikam/utilities/imageeditor/canvas/dimginterface.cpp
@@ -337,7 +337,7 @@ void DImgInterface::slotImageLoaded(const LoadingDescription &loadingDescription
}
else
{
- // To tqrepaint image in canvas before to ask about to apply ICC profile.
+ // To repaint image in canvas before to ask about to apply ICC profile.
emit signalImageLoaded(d->filename, valRet);
DImg preview = d->image.smoothScale(240, 180, TQSize::ScaleMin);
@@ -390,7 +390,7 @@ void DImgInterface::slotImageLoaded(const LoadingDescription &loadingDescription
DDebug() << "Embedded profile: " << trans.getEmbeddedProfileDescriptor() << endl;
- // To tqrepaint image in canvas before to ask about to apply ICC profile.
+ // To repaint image in canvas before to ask about to apply ICC profile.
emit signalImageLoaded(d->filename, valRet);
DImg preview = d->image.smoothScale(240, 180, TQSize::ScaleMin);
diff --git a/digikam/utilities/imageeditor/canvas/undocache.cpp b/digikam/utilities/imageeditor/canvas/undocache.cpp
index 81c5c34..4323fca 100644
--- a/digikam/utilities/imageeditor/canvas/undocache.cpp
+++ b/digikam/utilities/imageeditor/canvas/undocache.cpp
@@ -69,8 +69,8 @@ UndoCache::UndoCache()
KGlobal::instance()->aboutData()->programName() + '/');
d->cachePrefix = TQString("%1undocache-%2")
- .tqarg(cacheDir)
- .tqarg(getpid());
+ .arg(cacheDir)
+ .arg(getpid());
}
UndoCache::~UndoCache()
@@ -99,8 +99,8 @@ void UndoCache::clear()
bool UndoCache::putData(int level, int w, int h, int bytesDepth, uchar* data)
{
TQString cacheFile = TQString("%1-%2.bin")
- .tqarg(d->cachePrefix)
- .tqarg(level);
+ .arg(d->cachePrefix)
+ .arg(level);
TQFile file(cacheFile);
@@ -129,8 +129,8 @@ bool UndoCache::putData(int level, int w, int h, int bytesDepth, uchar* data)
uchar* UndoCache::getData(int level, int& w, int& h, int& bytesDepth, bool del)
{
TQString cacheFile = TQString("%1-%2.bin")
- .tqarg(d->cachePrefix)
- .tqarg(level);
+ .arg(d->cachePrefix)
+ .arg(level);
TQFile file(cacheFile);
if (!file.open(IO_ReadOnly))
@@ -166,8 +166,8 @@ uchar* UndoCache::getData(int level, int& w, int& h, int& bytesDepth, bool del)
void UndoCache::erase(int level)
{
TQString cacheFile = TQString("%1-%2.bin")
- .tqarg(d->cachePrefix)
- .tqarg(level);
+ .arg(d->cachePrefix)
+ .arg(level);
if(d->cacheFilenames.find(cacheFile) == d->cacheFilenames.end())
return;
diff --git a/digikam/utilities/imageeditor/editor/editorwindow.cpp b/digikam/utilities/imageeditor/editor/editorwindow.cpp
index cb75a31..a559f33 100644
--- a/digikam/utilities/imageeditor/editor/editorwindow.cpp
+++ b/digikam/utilities/imageeditor/editor/editorwindow.cpp
@@ -627,13 +627,13 @@ void EditorWindow::printImage(KURL url)
KPrinter::addDialogPage( new ImageEditorPrintDialogPage(image, this, TQString(appName.append(" page")).ascii() ));
- if ( printer.setup( this, i18n("Print %1").tqarg(printer.docName().section('/', -1)) ) )
+ if ( printer.setup( this, i18n("Print %1").arg(printer.docName().section('/', -1)) ) )
{
ImagePrint printOperations(image, printer, url.filename());
if (!printOperations.printImageWithTQt())
{
KMessageBox::error(this, i18n("Failed to print file: '%1'")
- .tqarg(url.filename()));
+ .arg(url.filename()));
}
}
}
@@ -1167,7 +1167,7 @@ bool EditorWindow::promptForOverWrite()
{
TQFileInfo fi(m_canvas->currentImageFilePath());
TQString warnMsg(i18n("About to overwrite file \"%1\"\nAre you sure?")
- .tqarg(fi.fileName()));
+ .arg(fi.fileName()));
return (KMessageBox::warningContinueCancel(this,
warnMsg,
i18n("Warning"),
@@ -1189,7 +1189,7 @@ bool EditorWindow::promptUserSave(const KURL& url)
int result = KMessageBox::warningYesNoCancel(this,
i18n("The image '%1' has been modified.\n"
"Do you want to save it?")
- .tqarg(url.filename()),
+ .arg(url.filename()),
TQString(),
KStdGuiItem::save(),
KStdGuiItem::discard());
@@ -1282,8 +1282,8 @@ void EditorWindow::slotSelected(bool val)
// Update status bar
if (val)
- d->selectLabel->setText(TQString("(%1, %2) (%3 x %4)").tqarg(sel.x()).tqarg(sel.y())
- .tqarg(sel.width()).tqarg(sel.height()));
+ d->selectLabel->setText(TQString("(%1, %2) (%3 x %4)").arg(sel.x()).arg(sel.y())
+ .arg(sel.width()).arg(sel.height()));
else
d->selectLabel->setText(i18n("No selection"));
}
@@ -1350,7 +1350,7 @@ void EditorWindow::slotLoadingFinished(const TQString& filename, bool success)
if (!success && filename != TQString())
{
TQFileInfo fi(filename);
- TQString message = i18n("Failed to load image \"%1\"").tqarg(fi.fileName());
+ TQString message = i18n("Failed to load image \"%1\"").arg(fi.fileName());
KMessageBox::error(this, message);
DWarning() << "Failed to load image " << fi.fileName() << endl;
}
@@ -1400,8 +1400,8 @@ void EditorWindow::slotSavingFinished(const TQString& filename, bool success)
if (!m_savingContext->abortingSaving)
{
KMessageBox::error(this, i18n("Failed to save file\n\"%1\"\nto\n\"%2\".")
- .tqarg(m_savingContext->destinationURL.filename())
- .tqarg(m_savingContext->destinationURL.path()));
+ .arg(m_savingContext->destinationURL.filename())
+ .arg(m_savingContext->destinationURL.path()));
}
finishSaving(false);
return;
@@ -1441,8 +1441,8 @@ void EditorWindow::slotSavingFinished(const TQString& filename, bool success)
if (!m_savingContext->abortingSaving)
{
KMessageBox::error(this, i18n("Failed to save file\n\"%1\"\nto\n\"%2\".")
- .tqarg(m_savingContext->destinationURL.filename())
- .tqarg(m_savingContext->destinationURL.path()));
+ .arg(m_savingContext->destinationURL.filename())
+ .arg(m_savingContext->destinationURL.path()));
}
finishSaving(false);
return;
@@ -1609,7 +1609,7 @@ bool EditorWindow::startingSaveAs(const KURL& url)
if ( !imgExtPattern.contains( m_savingContext->format.upper() ) )
{
KMessageBox::error(this, i18n("Target image file format \"%1\" unsupported.")
- .tqarg(m_savingContext->format));
+ .arg(m_savingContext->format));
DWarning() << k_funcinfo << "target image file format " << m_savingContext->format << " unsupported!" << endl;
return false;
}
@@ -1619,8 +1619,8 @@ bool EditorWindow::startingSaveAs(const KURL& url)
if (!newURL.isValid())
{
KMessageBox::error(this, i18n("Failed to save file\n\"%1\" to\n\"%2\".")
- .tqarg(newURL.filename())
- .tqarg(newURL.path().section('/', -2, -2)));
+ .arg(newURL.filename())
+ .arg(newURL.path().section('/', -2, -2)));
DWarning() << k_funcinfo << "target URL is not valid !" << endl;
return false;
}
@@ -1651,7 +1651,7 @@ bool EditorWindow::startingSaveAs(const KURL& url)
KMessageBox::warningYesNo( this, i18n("A file named \"%1\" already "
"exists. Are you sure you want "
"to overwrite it?")
- .tqarg(newURL.filename()),
+ .arg(newURL.filename()),
i18n("Overwrite File?"),
i18n("Overwrite"),
KStdGuiItem::cancel() );
@@ -1697,7 +1697,7 @@ bool EditorWindow::checkPermissions(const KURL& url)
"for the file named \"%1\". "
"Are you sure you want "
"to overwrite it?")
- .tqarg(url.filename()),
+ .arg(url.filename()),
i18n("Overwrite File?"),
i18n("Overwrite"),
KStdGuiItem::cancel() );
@@ -1867,8 +1867,8 @@ void EditorWindow::slotToggleSlideShow()
void EditorWindow::slotSelectionChanged(const TQRect& sel)
{
- d->selectLabel->setText(TQString("(%1, %2) (%3 x %4)").tqarg(sel.x()).tqarg(sel.y())
- .tqarg(sel.width()).tqarg(sel.height()));
+ d->selectLabel->setText(TQString("(%1, %2) (%3 x %4)").arg(sel.x()).arg(sel.y())
+ .arg(sel.width()).arg(sel.height()));
}
void EditorWindow::slotRawCameraList()
@@ -1905,7 +1905,7 @@ void EditorWindow::slotChangeTheme(const TQString& theme)
void EditorWindow::setToolStartProgress(const TQString& toolName)
{
m_nameLabel->setProgressValue(0);
- m_nameLabel->progressBarMode(StatusProgressBar::CancelProgressBarMode, TQString("%1: ").tqarg(toolName));
+ m_nameLabel->progressBarMode(StatusProgressBar::CancelProgressBarMode, TQString("%1: ").arg(toolName));
}
void EditorWindow::setToolProgress(int progress)
diff --git a/digikam/utilities/imageeditor/editor/imageiface.cpp b/digikam/utilities/imageeditor/editor/imageiface.cpp
index e1bedc9..aa842e0 100644
--- a/digikam/utilities/imageeditor/editor/imageiface.cpp
+++ b/digikam/utilities/imageeditor/editor/imageiface.cpp
@@ -190,7 +190,7 @@ uchar* ImageIface::getPreviewImage() const
}
TQSize sz(im->width(), im->height());
- sz.tqscale(d->constrainWidth, d->constrainHeight, TQSize::ScaleMin);
+ sz.scale(d->constrainWidth, d->constrainHeight, TQSize::ScaleMin);
d->previewImage = im->smoothScale(sz.width(), sz.height());
d->previewWidth = d->previewImage.width();
diff --git a/digikam/utilities/imageeditor/editor/imagewindow.cpp b/digikam/utilities/imageeditor/editor/imagewindow.cpp
index 897cba5..b3a1440 100644
--- a/digikam/utilities/imageeditor/editor/imagewindow.cpp
+++ b/digikam/utilities/imageeditor/editor/imagewindow.cpp
@@ -444,7 +444,7 @@ void ImageWindow::loadCurrentList(const TQString& caption, bool allowSaving)
}
if (!caption.isEmpty())
- setCaption(i18n("Image Editor - %1").tqarg(caption));
+ setCaption(i18n("Image Editor - %1").arg(caption));
else
setCaption(i18n("Image Editor"));
@@ -609,7 +609,7 @@ void ImageWindow::slotChanged()
TQSize dims(m_canvas->imageWidth(), m_canvas->imageHeight());
mpixels.setNum(dims.width()*dims.height()/1000000.0, 'f', 2);
TQString str = (!dims.isValid()) ? i18n("Unknown") : i18n("%1x%2 (%3Mpx)")
- .tqarg(dims.width()).tqarg(dims.height()).tqarg(mpixels);
+ .arg(dims.width()).arg(dims.height()).arg(mpixels);
m_resLabel->setText(str);
if (d->urlCurrent.isValid())
@@ -717,8 +717,8 @@ void ImageWindow::slotUpdateItemInfo()
m_rotatedOrFlipped = false;
TQString text = d->urlCurrent.filename() + i18n(" (%2 of %3)")
- .tqarg(TQString::number(index+1))
- .tqarg(TQString::number(d->urlList.count()));
+ .arg(TQString::number(index+1))
+ .arg(TQString::number(d->urlList.count()));
m_nameLabel->setText(text);
if (d->urlList.count() == 1)
@@ -1178,7 +1178,7 @@ void ImageWindow::dropEvent(TQDropEvent *e)
if (talbum) ATitle = talbum->title();
loadImageInfos(imageInfoList, imageInfoList.first(),
- i18n("Album \"%1\"").tqarg(ATitle), true);
+ i18n("Album \"%1\"").arg(ATitle), true);
e->accept();
}
else if (AlbumDrag::decode(e, urls, albumID))
@@ -1205,7 +1205,7 @@ void ImageWindow::dropEvent(TQDropEvent *e)
if (palbum) ATitle = palbum->title();
loadImageInfos(imageInfoList, imageInfoList.first(),
- i18n("Album \"%1\"").tqarg(ATitle), true);
+ i18n("Album \"%1\"").arg(ATitle), true);
e->accept();
}
else if(TagDrag::canDecode(e))
@@ -1237,7 +1237,7 @@ void ImageWindow::dropEvent(TQDropEvent *e)
if (talbum) ATitle = talbum->title();
loadImageInfos(imageInfoList, imageInfoList.first(),
- i18n("Album \"%1\"").tqarg(ATitle), true);
+ i18n("Album \"%1\"").arg(ATitle), true);
e->accept();
}
else
diff --git a/digikam/utilities/imageeditor/rawimport/rawpreview.cpp b/digikam/utilities/imageeditor/rawimport/rawpreview.cpp
index e1581ae..3bdd5cc 100644
--- a/digikam/utilities/imageeditor/rawimport/rawpreview.cpp
+++ b/digikam/utilities/imageeditor/rawimport/rawpreview.cpp
@@ -186,7 +186,7 @@ void RawPreview::slotImageLoaded(const LoadingDescription& description, const DI
p.drawText(0, 0, pix.width(), pix.height(),
TQt::AlignCenter|TQt::WordBreak,
i18n("Cannot decode RAW image for\n\"%1\"")
- .tqarg(TQFileInfo(d->loadingDesc.filePath).fileName()));
+ .arg(TQFileInfo(d->loadingDesc.filePath).fileName()));
p.end();
// three copies - but the image is small
setPostProcessedImage(DImg(pix.convertToImage()));
diff --git a/digikam/utilities/imageeditor/rawimport/rawsettingsbox.cpp b/digikam/utilities/imageeditor/rawimport/rawsettingsbox.cpp
index 3bc4100..1981276 100644
--- a/digikam/utilities/imageeditor/rawimport/rawsettingsbox.cpp
+++ b/digikam/utilities/imageeditor/rawimport/rawsettingsbox.cpp
@@ -560,7 +560,7 @@ void RawSettingsBox::readSettings()
for (int j = 0 ; j <= 17 ; j++)
{
TQPoint disable(-1, -1);
- TQPoint p = config->readPointEntry(TQString("CurveAjustmentPoint%1").tqarg(j), &disable);
+ TQPoint p = config->readPointEntry(TQString("CurveAjustmentPoint%1").arg(j), &disable);
if (!d->decodingSettingsBox->sixteenBits() && p != disable)
{
// Restore point as 16 bits depth.
@@ -627,7 +627,7 @@ void RawSettingsBox::writeSettings()
p.setX(p.x()*255);
p.setY(p.y()*255);
}
- config->writeEntry(TQString("CurveAjustmentPoint%1").tqarg(j), p);
+ config->writeEntry(TQString("CurveAjustmentPoint%1").arg(j), p);
}
config->writeEntry("Settings Page", d->tabView->currentPage());
@@ -709,13 +709,13 @@ void RawSettingsBox::slotChannelChanged(int channel)
break;
}
- d->histogramWidget->tqrepaint(false);
+ d->histogramWidget->repaint(false);
}
void RawSettingsBox::slotScaleChanged(int scale)
{
d->histogramWidget->m_scaleType = scale;
- d->histogramWidget->tqrepaint(false);
+ d->histogramWidget->repaint(false);
}
void RawSettingsBox::slotColorsChanged(int color)
@@ -735,7 +735,7 @@ void RawSettingsBox::slotColorsChanged(int color)
break;
}
- d->histogramWidget->tqrepaint(false);
+ d->histogramWidget->repaint(false);
}
} // NameSpace Digikam
diff --git a/digikam/utilities/imageeditor/tools/imageprint.cpp b/digikam/utilities/imageeditor/tools/imageprint.cpp
index 8589e93..fb29f72 100644
--- a/digikam/utilities/imageeditor/tools/imageprint.cpp
+++ b/digikam/utilities/imageeditor/tools/imageprint.cpp
@@ -175,7 +175,7 @@ bool ImagePrint::printImageWithTQt()
: KPrinter::Landscape );
// Scale image to fit pagesize
- size.tqscale( w, h, TQSize::ScaleMin );
+ size.scale( w, h, TQSize::ScaleMin );
}
else
{
@@ -217,32 +217,32 @@ bool ImagePrint::printImageWithTQt()
}
else if (resp == KMessageBox::No)
{ // Shrink
- size.tqscale(w, h, TQSize::ScaleMin);
+ size.scale(w, h, TQSize::ScaleMin);
}
}
}
// Align image.
- int tqalignment = (m_printer.option("app-imageeditor-tqalignment").isEmpty() ?
- TQt::AlignCenter : m_printer.option("app-imageeditor-tqalignment").toInt());
+ int alignment = (m_printer.option("app-imageeditor-alignment").isEmpty() ?
+ TQt::AlignCenter : m_printer.option("app-imageeditor-alignment").toInt());
int x = 0;
int y = 0;
- // x - tqalignment
- if ( tqalignment & TQt::AlignHCenter )
+ // x - alignment
+ if ( alignment & TQt::AlignHCenter )
x = (w - size.width())/2;
- else if ( tqalignment & TQt::AlignLeft )
+ else if ( alignment & TQt::AlignLeft )
x = 0;
- else if ( tqalignment & TQt::AlignRight )
+ else if ( alignment & TQt::AlignRight )
x = w - size.width();
- // y - tqalignment
- if ( tqalignment & TQt::AlignVCenter )
+ // y - alignment
+ if ( alignment & TQt::AlignVCenter )
y = (h - size.height())/2;
- else if ( tqalignment & TQt::AlignTop )
+ else if ( alignment & TQt::AlignTop )
y = 0;
- else if ( tqalignment & TQt::AlignBottom )
+ else if ( alignment & TQt::AlignBottom )
y = h - size.height();
// Perform the actual drawing.
@@ -492,7 +492,7 @@ void ImageEditorPrintDialogPage::getOptions( TQMap<TQString,TQString>& opts, boo
TQString t = "true";
TQString f = "false";
- opts["app-imageeditor-tqalignment"] = TQString::number(getPosition(d->position->currentText()));
+ opts["app-imageeditor-alignment"] = TQString::number(getPosition(d->position->currentText()));
opts["app-imageeditor-printFilename"] = d->addFileName->isChecked() ? t : f;
opts["app-imageeditor-blackwhite"] = d->blackwhite->isChecked() ? t : f;
opts["app-imageeditor-scaleToFit"] = d->scaleToFit->isChecked() ? t : f;
@@ -514,7 +514,7 @@ void ImageEditorPrintDialogPage::setOptions( const TQMap<TQString,TQString>& opt
double dVal;
int iVal;
- iVal = opts["app-imageeditor-tqalignment"].toInt( &ok );
+ iVal = opts["app-imageeditor-alignment"].toInt( &ok );
if (ok)
{
stVal = setPosition(iVal);
@@ -563,92 +563,92 @@ void ImageEditorPrintDialogPage::setOptions( const TQMap<TQString,TQString>& opt
}
int ImageEditorPrintDialogPage::getPosition(const TQString& align)
{
- int tqalignment;
+ int alignment;
if (align == i18n("Central-Left"))
{
- tqalignment = TQt::AlignLeft | TQt::AlignVCenter;
+ alignment = TQt::AlignLeft | TQt::AlignVCenter;
}
else if (align == i18n("Central-Right"))
{
- tqalignment = TQt::AlignRight | TQt::AlignVCenter;
+ alignment = TQt::AlignRight | TQt::AlignVCenter;
}
else if (align == i18n("Top-Left"))
{
- tqalignment = TQt::AlignTop | TQt::AlignLeft;
+ alignment = TQt::AlignTop | TQt::AlignLeft;
}
else if (align == i18n("Top-Right"))
{
- tqalignment = TQt::AlignTop | TQt::AlignRight;
+ alignment = TQt::AlignTop | TQt::AlignRight;
}
else if (align == i18n("Bottom-Left"))
{
- tqalignment = TQt::AlignBottom | TQt::AlignLeft;
+ alignment = TQt::AlignBottom | TQt::AlignLeft;
}
else if (align == i18n("Bottom-Right"))
{
- tqalignment = TQt::AlignBottom | TQt::AlignRight;
+ alignment = TQt::AlignBottom | TQt::AlignRight;
}
else if (align == i18n("Top-Central"))
{
- tqalignment = TQt::AlignTop | TQt::AlignHCenter;
+ alignment = TQt::AlignTop | TQt::AlignHCenter;
}
else if (align == i18n("Bottom-Central"))
{
- tqalignment = TQt::AlignBottom | TQt::AlignHCenter;
+ alignment = TQt::AlignBottom | TQt::AlignHCenter;
}
else
{
// Central
- tqalignment = TQt::AlignCenter; // TQt::AlignHCenter || TQt::AlignVCenter
+ alignment = TQt::AlignCenter; // TQt::AlignHCenter || TQt::AlignVCenter
}
- return tqalignment;
+ return alignment;
}
TQString ImageEditorPrintDialogPage::setPosition(int align)
{
- TQString tqalignment;
+ TQString alignment;
if (align == (TQt::AlignLeft | TQt::AlignVCenter))
{
- tqalignment = i18n("Central-Left");
+ alignment = i18n("Central-Left");
}
else if (align == (TQt::AlignRight | TQt::AlignVCenter))
{
- tqalignment = i18n("Central-Right");
+ alignment = i18n("Central-Right");
}
else if (align == (TQt::AlignTop | TQt::AlignLeft))
{
- tqalignment = i18n("Top-Left");
+ alignment = i18n("Top-Left");
}
else if (align == (TQt::AlignTop | TQt::AlignRight))
{
- tqalignment = i18n("Top-Right");
+ alignment = i18n("Top-Right");
}
else if (align == (TQt::AlignBottom | TQt::AlignLeft))
{
- tqalignment = i18n("Bottom-Left");
+ alignment = i18n("Bottom-Left");
}
else if (align == (TQt::AlignBottom | TQt::AlignRight))
{
- tqalignment = i18n("Bottom-Right");
+ alignment = i18n("Bottom-Right");
}
else if (align == (TQt::AlignTop | TQt::AlignHCenter))
{
- tqalignment = i18n("Top-Central");
+ alignment = i18n("Top-Central");
}
else if (align == (TQt::AlignBottom | TQt::AlignHCenter))
{
- tqalignment = i18n("Bottom-Central");
+ alignment = i18n("Bottom-Central");
}
else
{
// Central: TQt::AlignCenter or (TQt::AlignHCenter || TQt::AlignVCenter)
- tqalignment = i18n("Central");
+ alignment = i18n("Central");
}
- return tqalignment;
+ return alignment;
}
void ImageEditorPrintDialogPage::toggleScaling( bool enable )
diff --git a/digikam/utilities/imageeditor/tools/imageresize.cpp b/digikam/utilities/imageeditor/tools/imageresize.cpp
index 2895c4e..d473b77 100644
--- a/digikam/utilities/imageeditor/tools/imageresize.cpp
+++ b/digikam/utilities/imageeditor/tools/imageresize.cpp
@@ -617,7 +617,7 @@ void ImageResize::slotUser3()
{
KMessageBox::error(this,
i18n("\"%1\" is not a Photograph Resizing settings text file.")
- .tqarg(loadBlowupFile.fileName()));
+ .arg(loadBlowupFile.fileName()));
file.close();
return;
}
diff --git a/digikam/utilities/imageeditor/canvas/canvas.cpp b/digikam/utilities/imageeditor/canvas/canvas.cpp
index 06a99b7..1dec7b4 100644
--- a/digikam/utilities/imageeditor/canvas/canvas.cpp
+++ b/digikam/utilities/imageeditor/canvas/canvas.cpp
@@ -469,7 +469,7 @@ void Canvas::resizeEvent(TQResizeEvent* e)
updateContentsSize(false);
// No need to tqrepaint. its called
// automatically after resize
// To be sure than corner widget used to pan image will be hide/show
@@ -523,7 +523,7 @@ void Canvas::paintViewport(const TQRect& er, bool antialias)
{
for (int i = x1 ; i < x2 ; i += d->tileSize)
{
- TQString key = TQString("%1,%2").tqarg(i).tqarg(j);
+ TQString key = TQString("%1,%2").arg(i).arg(j);
TQPixmap *pix = d->tileCache.find(key);
if (!pix)
@@ -690,7 +690,7 @@ void Canvas::contentsMousePressEvent(TQMouseEvent *e)
d->pressedMoving = true;
d->tileCache.clear();
- viewport()->tqrepaint(false);
+ viewport()->repaint(false);
return;
}
@@ -469,7 +469,7 @@ void Canvas::resizeEvent(TQResizeEvent* e)
updateContentsSize(false);
- // No need to tqrepaint. its called
+ // No need to repaint. its called
// automatically after resize
// To be sure than corner widget used to pan image will be hide/show